Module enter_ssa

Module enter_ssa 

Functions

enter_ssa
placeholder_function
Create a placeholder HirFunction for temporarily swapping an inner function out of env.functions via std::mem::replace. The placeholder is never read — the real function is swapped back immediately after processing.