placeholder_function

Function placeholder_function 

pub fn placeholder_function() -> HirFunction
Create a placeholder HirFunction for temporarily swapping an inner function out of env.functions via std::mem::replace. The placeholder is never read — the real function is swapped back immediately after processing.